@@ -998,7 +998,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
         if self.Output is None:
             self.Output = {}
         if 'CelexCategory' not in self.Output:
-            cat = lookupCat(self.WordType.Label)
+            cat = self.WordType.get_celex_info()['CelexCategory']
             self.Output['CelexCategory'] = cat
             self.save()
         return self.Output['CelexCategory']
@@ -1047,7 +1047,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
                     outline['wasRepeated'] = 'False'
         celex_info = self.WordType.get_celex_info()
         if 'CelexCategory' not in outline:
-            outline['CelexCategory'] = celex_info['Cat']
+            outline['CelexCategory'] = celex_info['CelexCategory']
 
         if 'B' in form['category']:
             if 'BuckeyeCategory' not in outline:
@@ -1061,7 +1061,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
         if form['frequency']:
             if 'C' in form['lexical_scale'] and 'CelexFrequency' not in outline:
                 try:
-                    outline['CelexFrequency'] = celex_info['Freq']
+                    outline['CelexFrequency'] = celex_info['CelexFrequency']
                 except KeyError:
                     outline['CelexFrequency'] = 'NA'
             if 'W' in form['lexical_scale'] and 'BuckeyeFrequency' not in outline:
@@ -1091,7 +1091,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
         if form['nd']:
             if 'C' in form['lexical_scale'] and 'CelexNeighDen' not in outline:
                 try:
-                    outline['CelexNeighDen'],outline['CelexFWND'] = celex_info['ND'],celex_info['FWND']
+                    outline['CelexNeighDen'],outline['CelexFWND'] = celex_info['CelexNeighDen'],celex_info['CelexFWND']
                 except KeyError:
                     outline['CelexNeighDen'],outline['CelexFWND'] = 'NA','NA'
             if 'W' in form['lexical_scale'] and 'BuckeyeNeighDen' not in outline:
@@ -1108,7 +1108,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
         if form['phonotactic']:
             if 'C' in form['lexical_scale'] and 'CelexSPhoneProb' not in outline:
                 try:
-                    outline['CelexSPhoneProb'],outline['CelexBiPhoneProb'] = celex_info['SP'],celex_info['BP']
+                    outline['CelexSPhoneProb'],outline['CelexBiPhoneProb'] = celex_info['CelexSPhoneProb'],celex_info['CelexBiPhoneProb']
                 except KeyError:
                     outline['CelexSPhoneProb'],outline['CelexBiPhoneProb'] = 'NA','NA'
             if 'W' in form['lexical_scale'] and 'BuckeyeSPhoneProb' not in outline:
